Learn R Programming

irtpwr (version 1.0.3)

calc.time: Calculate the computation time needed for the analytical method

Description

Calculate the computation time needed for the analytical method

Usage

calc.time(hyp, n.items)

Value

Numeric, estimated time in seconds

Arguments

hyp

Hypothesis object as created by the setup.hypothesis function

n.items

Number of items

Examples

Run this code
# \donttest{
library(mirt)
dat <- expand.table(LSAT7)
mirtfit <- mirt(dat,1,verbose = FALSE)
hyp <- setup.hypothesis(type = '1PLvs2PL', altpars = mirtfit)
calc.time(hyp,n.items=7)
# }

Run the code above in your browser using DataLab