Learn R Programming

irtpwr (version 1.0.3)

summary.irtpwrresult: Summary of the Power Analysis

Description

Output the resulting power or sample size for each statistic

Usage

# S3 method for irtpwrresult
summary(object, ..., power = NULL, N = NULL, alpha = NULL)

Value

An object of class summary.irtpwrresult

Arguments

object

Object of class irtpwrresult as created by the irtpwr function

...

additional arguments to be passed

power

numeric, statistical power for which the necessary sample size is calculated

N

integer, sample size for which the statistical power is calculated.

alpha

numeric, alpha level

Examples

Run this code
# \donttest{

library(mirt)
dat <- expand.table(LSAT7)
mirtfit <- mirt(dat,1,verbose = FALSE)
hyp <- setup.hypothesis(type = '1PLvs2PL', altpars = mirtfit)
res <- irtpwr(hyp=hyp,alpha=.05,power =.8)
summary(res)
# }

Run the code above in your browser using DataLab