powered by
This is a helper function used to generate custom hypotheses. See the 'adding_hypotheses' vignette.
pars.long(pars, itemtype, from.mirt = FALSE)
numeric vector
list of parameters. Can also be coefficients from a model fitted by mirt. In this case, the from.mirt argument has to be set to TRUE
character, type of the item as string, e.g. '2PL'
logical, treat as coefficients from a model fitted by mirt if TRUE
pars = list(a= c(1,1,1),d=c(0,0,0)) pars.long(pars,itemtype='2PL')
Run the code above in your browser using DataLab